from .racing_code import RacingCode as RacingCode
from _typeshed import Incomplete
from peak_utility.number import RepresentationalInt

class RaceGrade(RepresentationalInt):
    REGEX: str
    PHRASES: Incomplete
    def __new__(cls, grade: str | int | None, racing_code: RacingCode | None = None): ...
    def __bool__(self) -> bool: ...
    def __hash__(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __gt__(self, other): ...
