from peak_utility.enumeration.parsing_enum import ParsingEnum

class Breed(ParsingEnum):
    THOROUGHBRED: int
    ARABIAN: int
    QUARTER_HORSE: int
    AQPS: int
    TB = THOROUGHBRED
    QH = QUARTER_HORSE
