from peak_utility.enumeration.parsing_enum import ParsingEnum

class Surface(ParsingEnum):
    TURF: int
    DIRT: int
    ALL_WEATHER: int
    POLYTRACK: int
    TAPETA: int
    FIBRESAND: int
    T = TURF
    D = DIRT
    AW = ALL_WEATHER
