from .disaster import Disaster as Disaster
from .finishing_position import FinishingPosition as FinishingPosition
from typing import Self

class Outcome:
    def __init__(self, value: int | str | Disaster | FinishingPosition) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __lt__(self, other: Self) -> bool: ...
    def __le__(self, other: Self) -> bool: ...
    def __gt__(self, other: Self) -> bool: ...
    def __ge__(self, other: Self) -> bool: ...
    @property
    def is_completion(self) -> bool: ...
    @property
    def is_win(self) -> bool: ...
