from peak_utility.enumeration.parsing_enum import ParsingEnum

class CoatColour(ParsingEnum):
    BAY: int
    BLACK: int
    CHESTNUT: int
    DARK_BAY: int
    GREY: int
    PALOMINO: int
    WHITE: int
    ROAN: int
    B = BAY
    BL = BLACK
    C = CHESTNUT
    CH = CHESTNUT
    DB = DARK_BAY
    BR = DARK_BAY
    G = GREY
    GR = GREY
    GRAY = GREY
    P = PALOMINO
    W = WHITE
    R = ROAN
    RO = ROAN
