from peak_utility.enumeration.parsing_enum import ParsingEnum

class JockeyExperienceLevel(ParsingEnum):
    AMATEUR: int
    CONDITIONAL: int
    APPRENTICE: int
    PROFESSIONAL: int
    AMATEURS = AMATEUR
    CONDITIONALS = CONDITIONAL
    APPRENTICES = APPRENTICE
    PROFESSIONALS = PROFESSIONAL
