from .aw_going_description import AWGoingDescription as AWGoingDescription
from .dirt_going_description import DirtGoingDescription as DirtGoingDescription
from .going_description import GoingDescription as GoingDescription
from .surface import Surface as Surface
from .turf_going_description import TurfGoingDescription as TurfGoingDescription
from _typeshed import Incomplete

class Going:
    Scales: Incomplete
    description: Incomplete
    reading: Incomplete
    def __init__(self, description: str, reading: float | None = None) -> None: ...
    def __hash__(self): ...
    def __eq__(self, other: object) -> bool: ...
    @property
    def primary(self) -> GoingDescription: ...
    @property
    def secondary(self) -> GoingDescription | None: ...
    @property
    def surface(self) -> Surface: ...
    @property
    def value(self) -> float: ...
    @staticmethod
    def multiparse(description: str) -> dict[str, 'Going']: ...
